==> buildfile_1.0.0_for_2.1_src.zip: org.vivianj.eclipse.plugin.buildfile/src/org/vivianj/eclipse/plugin/buildfile/listener/ProjectTreeSelectionListener.java <==
/*
 * 2004-10-22 Фݼ 
 */
package org.vivianj.eclipse.plugin.buildfile.listener;

import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.events.SelectionListener;
import org.eclipse.swt.widgets.Group;
import org.eclipse.swt.widgets.Tree;
import org.eclipse.swt.widgets.TreeItem;
import org.eclipse.ui.editors.text.TextEditor;
import org.vivianj.eclipse.plugin.buildfile.group.RightGroup;
import org.vivianj.eclipse.plugin.buildfile.util.ControlDispose;
import org.vivianj.eclipse.plugin.buildfile.util.GroupFactory;

/**
 * ProjectTreeSelectionListenerڵĵ¼
 */
public class ProjectTreeSelectionListener implements SelectionListener {
	/** ʾ */
	private Tree tree;

	/** Ұ벿ʾ */
	private Group group;

	private TextEditor editor;

	private TreeItem selection = null;

	/**
	 * ProjectTreeSelectionListener
	 */
	public ProjectTreeSelectionListener() {

	}

	/**
	 * ProjectTreeSelectionListener
	 * 
	 * @param p_tree
	 *            ʵ
	 * @param p_group
	 *            ڵʾʵ
	 * @param p_editor
	 *            ITextEditorʵ
	 */
	public ProjectTreeSelectionListener(Tree p_tree, Group p_group,
			TextEditor p_editor) {
		this.tree = p_tree;

		this.group = p_group;

		this.editor = p_editor;
	}

	/*
	 * 굥¼
	 */
	public void widgetSelected(SelectionEvent arg0) {
		TreeItem treeItem[] = this.tree.getSelection();
		int i = this.tree.getSelectionCount();
		if (i > 0) {
			selection = treeItem[0];
			Object o = selection.getData();

			//еĿؼ
			ControlDispose.disposeControls(this.group);

			//µ
			this.createGroup(o);
		}

	}

	public void widgetDefaultSelected(SelectionEvent arg0) {
	}

	/*
	 * ݱѡڵ㴴µĽڵʾ
	 */
	private void createGroup(Object o) {
		//		µ
		RightGroup rightGroup = GroupFactory.getGroup(o, this.group,
				this.selection);
		rightGroup.createPanel(RightGroup.UPDATE);
		rightGroup.setEditor(this.editor);
		//      ˢ½
		this.redraw();
	}

	/*
	 * ػ¼
	 */
	private void redraw() {
		this.group.layout();
		this.group.getParent().layout();
	}
}

==> buildfile_1.2.36_for_3.0_src.zip: org.vivianj.eclipse.plugin.buildfile/src/org/vivianj/eclipse/plugin/buildfile/listener/ProjectTreeSelectionListener.java <==
/*
 * 2004-10-22 Фݼ 
 */
package org.vivianj.eclipse.plugin.buildfile.listener;

import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.events.SelectionListener;
import org.eclipse.swt.widgets.Group;
import org.eclipse.swt.widgets.Tree;
import org.eclipse.swt.widgets.TreeItem;
import org.eclipse.ui.editors.text.TextEditor;
import org.vivianj.eclipse.plugin.buildfile.group.PropertyGroup;
import org.vivianj.eclipse.plugin.buildfile.group.RightGroup;
import org.vivianj.eclipse.plugin.buildfile.util.ControlDispose;

/**
 * ProjectTreeSelectionListenerڵĵ¼
 */
public class ProjectTreeSelectionListener implements SelectionListener {
	/** ʾ */
	private Tree tree;

	/** Ұ벿ʾ */
	private Group group;

	private TextEditor editor;

	private TreeItem selection = null;

	/**
	 * ProjectTreeSelectionListener
	 */
	public ProjectTreeSelectionListener() {

	}

	/**
	 * ProjectTreeSelectionListener
	 * 
	 * @param p_tree
	 *            ʵ
	 * @param p_group
	 *            ڵʾʵ
	 * @param p_editor
	 *            ITextEditorʵ
	 */
	public ProjectTreeSelectionListener(Tree p_tree, Group p_group,
			TextEditor p_editor) {
		this.tree = p_tree;

		this.group = p_group;

		this.editor = p_editor;
	}

	/*
	 * 굥¼
	 */
	public void widgetSelected(SelectionEvent arg0) {
		TreeItem treeItem[] = this.tree.getSelection();
		int i = this.tree.getSelectionCount();
		if (i > 0) {
			selection = treeItem[0];
			
			Object o = selection.getData();

			//еĿؼ
			ControlDispose.disposeControls(this.group);

			//µ
			this.createGroup(o);
		}

	}

	public void widgetDefaultSelected(SelectionEvent arg0) {
	}

	/*
	 * ݱѡڵ㴴µĽڵʾ
	 */
	private void createGroup(Object o) {
		//		µ
		RightGroup rightGroup = new PropertyGroup(this.group,
				this.selection);
		rightGroup.createPanel();
		rightGroup.setEditor(this.editor);
		//      ˢ½
		this.redraw();
	}

	/*
	 * ػ¼
	 */
	private void redraw() {
		this.group.layout();
		this.group.getParent().layout();
	}
}
